# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ....._models import BaseModel
from .mdr_usage_report_response_legacy import MdrUsageReportResponseLegacy

__all__ = ["MessagingDeleteResponse"]


class MessagingDeleteResponse(BaseModel):
    data: Optional[MdrUsageReportResponseLegacy] = None
    """Legacy V2 MDR usage report response"""
