# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["TelnyxConversationChannel"]

TelnyxConversationChannel: TypeAlias = Literal["phone_call", "web_call", "sms_chat", "web_chat"]
